@@ -48,6 +48,7 @@ namespace Oxygen
         registerEngine( _groupBoxLabelEngine = new GroupBoxLabelEngine( this ) );
         registerEngine( _hoverEngine = new HoverEngine( this ) );
         registerEngine( _mainWindowEngine = new MainWindowEngine( this ) );
+        registerEngine( _menuItemEngine = new MenuItemEngine( this ) );
         registerEngine( _panedEngine = new PanedEngine( this ) );
         registerEngine( _scrollBarEngine = new ScrollBarEngine( this ) );
         registerEngine( _scrolledWindowEngine = new ScrolledWindowEngine( this ) );
@@ -309,8 +310,6 @@ namespace Oxygen
     gboolean Animations::innerShadowHook( GSignalInvocationHint*, guint, const GValue* params, gpointer data )
     {
 
-        #if GTK_CHECK_VERSION(2,24,2)
-
         // get widget from params
         GtkWidget* widget( GTK_WIDGET( g_value_get_object( params ) ) );
 
@@ -344,7 +343,6 @@ namespace Oxygen
         animations.innerShadowEngine().registerWidget( parent );
         animations.innerShadowEngine().registerChild( parent, widget );
 
-        #endif  // Gtk version
         return TRUE;
 
     }
