@@ -94,22 +94,17 @@ namespace Oxygen
         _provider( gtk_css_provider_new() )
     {}
 
-    //_________________________________________________________
-    QtSettings::~QtSettings( void )
-    {
-
-        // free provider
-        g_free( _provider );
-
-    }
-
     //_________________________________________________________
     void QtSettings::loadKdeGlobals( void )
     {
 
         _kdeGlobals.clear();
         for( PathList::const_reverse_iterator iter = _kdeConfigPathList.rbegin(); iter != _kdeConfigPathList.rend(); ++iter )
-        { _kdeGlobals.merge( OptionMap( sanitizePath( *iter + "/kdeglobals" ) ) ); }
+        {
+            const std::string filename( sanitizePath( *iter + "/kdeglobals" ) );
+            _kdeGlobals.merge( OptionMap( filename ) );
+            monitorFile( filename );
+        }
 
         #if OXYGEN_DEBUG
         std::cerr << "Oxygen::QtSettings::loadKdeGlobals - kdeglobals: " << std::endl;
@@ -188,19 +183,8 @@ namespace Oxygen
             generateGtkColors();
         }
 
-        // deal with pathbar button margins
-        // this needs to be done programatically in order to properly account for RTL locales
-        _css.addSection( "GtkPathBar>GtkToggleButton" );
-        if( gtk_widget_get_default_direction() == GTK_TEXT_DIR_RTL )
-        {
-
-            _css.addToCurrentSection( "  -GtkButton-inner-border: 1px 0px 0px 10px;" );
-
-        } else {
-
-            _css.addToCurrentSection( "  -GtkButton-inner-border: 1px 10px 0px 0px;" );
-
-        }
+        // apply extra programatically set metrics metrics
+        loadExtraOptions();
 
         // print generated Gtkrc and commit
         #if OXYGEN_DEBUG
@@ -649,6 +633,7 @@ namespace Oxygen
 //         else _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_COLOR, _palette.color( Palette::SelectedText ) ) );
 
         _css.addSection( "GtkEntry:selected, GtkTreeView:selected, GtkTextView:selected" );
+        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, _palette.color( Palette::Selected ) ) );
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_COLOR, _palette.color( Palette::SelectedText ) ) );
 
          // buttons and comboboxes
@@ -837,7 +822,11 @@ namespace Oxygen
 
         OptionMap oxygen;
         for( PathList::const_reverse_iterator iter = _kdeConfigPathList.rbegin(); iter != _kdeConfigPathList.rend(); ++iter )
-        { oxygen.merge( OptionMap( sanitizePath( *iter + "/oxygenrc" ) ) ); }
+        {
+            const std::string filename( sanitizePath( *iter + "/oxygenrc" ) );
+            oxygen.merge( filename );
+            monitorFile( filename );
+        }
 
         #if OXYGEN_DEBUG
         std::cerr << "Oxygen::QtSettings::loadOxygenOptions - Oxygenrc: " << std::endl;
@@ -1027,6 +1016,59 @@ namespace Oxygen
 
     }
 
+    //_________________________________________________________
+    void QtSettings::loadExtraOptions( void )
+    {
+
+        #if GTK_CHECK_VERSION( 3, 3, 0 )
+
+        // button padding
+        _css.setCurrentSection( "GtkButton" );
+        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_PADDING, "3px 2px 2px" ) );
+
+        // pathbar button margins
+        _css.addSection( "GtkPathBar>GtkToggleButton" );
+        _css.addToCurrentSection(
+            ( gtk_widget_get_default_direction() == GTK_TEXT_DIR_RTL ) ?
+            Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_PADDING, "3px 2px 2px 12px;" ):
+            Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_PADDING, "3px 12px 2px 2px;" ) );
+
+        // spinbox buttons
+        _css.addSection( "GtkSpinButton.button" );
+        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, "alpha( #900185, 0 )" ) );
+        _css.addToCurrentSection( ( gtk_widget_get_default_direction() == GTK_TEXT_DIR_RTL ) ?
+            Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_PADDING, "0px 12px 0px 0px" ):
+            Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_PADDING, "0px 0px 0px 12px" ) );
+
+        // entries
+        _css.addSection( "GtkEntry" );
+        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_PADDING, "4px 7px" ) );
+
+        #else
+
+        // pathbar button margins
+        _css.addSection( "GtkPathBar>GtkToggleButton" );
+        _css.addToCurrentSection( (gtk_widget_get_default_direction() == GTK_TEXT_DIR_RTL ) ?
+            "  -GtkButton-inner-border: 1px 0px 0px 10px;":
+            "  -GtkButton-inner-border: 1px 10px 0px 0px;" );
+
+        // button padding
+        _css.setCurrentSection( Gtk::CSS::defaultSection() );
+        _css.addToCurrentSection( "  -GtkButton-inner-border: 1px 2px 0px;" );
+        _css.addToCurrentSection( "  -GtkCalendar-inner-border: 0px;" );
+
+        // toggle button
+        _css.addSection( "GtkToggleButton" );
+        _css.addToCurrentSection( "  -GtkButton-inner-border: 1px 0px 0px;" );
+
+        // entries
+        _css.addSection( "GtkEntry" );
+        _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_PADDING, "2px 5px" ) );
+
+        #endif
+
+    }
+
     //_________________________________________________________
     std::string QtSettings::sanitizePath( const std::string& path ) const
     {
@@ -1039,4 +1081,48 @@ namespace Oxygen
         return out;
     }
 
+    //_________________________________________________________
+    void QtSettings::monitorFile( const std::string& filename )
+    {
+
+        // check if file was already added
+        if( _monitoredFiles.find( filename ) != _monitoredFiles.end() )
+        { return; }
+
+        // check file existence
+        if( !std::ifstream( filename.c_str() ) )
+        { return; }
+
+        // create FileMonitor
+        FileMonitor monitor;
+        monitor.file = g_file_new_for_path( filename.c_str() );
+        if( ( monitor.monitor = g_file_monitor( monitor.file, G_FILE_MONITOR_NONE, 0L, 0L ) ) )
+        {
+
+            // insert in map
+            _monitoredFiles.insert( std::make_pair( filename, monitor ) );
+
+        } else {
+
+            // clear file and return
+            g_object_unref( monitor.file );
+            return;
+
+        }
+
+    }
+
+    //_________________________________________________________
+    void QtSettings::clearMonitoredFiles( void )
+    {
+        for( FileMap::iterator iter = _monitoredFiles.begin(); iter != _monitoredFiles.end(); iter++ )
+        {
+            iter->second.signal.disconnect();
+            g_object_unref( iter->second.file );
+            g_object_unref( iter->second.monitor );
+        }
+
+        _monitoredFiles.clear();
+    }
+
 }
