@@ -22,7 +22,6 @@
 #include "oxygenthemingengine.h"
 
 #include "oxygencairoutils.h"
-#include "oxygendbus.h"
 #include "oxygengtktypenames.h"
 #include "oxygengtkutils.h"
 #include "oxygenmetrics.h"
@@ -572,15 +571,24 @@ namespace Oxygen
             } else if( gtk_theming_engine_has_class( engine, GTK_STYLE_CLASS_SCALE ) && GTK_IS_SCALE( widget ) ) {
 
                 const bool vertical( Gtk::gtk_widget_is_vertical( widget ) );
+
                 const int offset( 6 );
-                if( vertical ) {
+                TileSet::Tiles tiles( TileSet::Full );
 
-                    Style::instance().renderSliderGroove( context, x, y + offset, w, h - 2*offset, Vertical );
+                #if GTK_CHECK_VERSION( 3, 3, 0 )
+                if( gtk_theming_engine_has_class( engine, GTK_STYLE_CLASS_LEFT ) ) { tiles &= ~TileSet::Right; x += offset; }
+                else if( gtk_theming_engine_has_class( engine, GTK_STYLE_CLASS_RIGHT ) ) { tiles &= ~TileSet::Left; w -= offset; }
+                else if( gtk_theming_engine_has_class( engine, GTK_STYLE_CLASS_TOP ) ) { tiles &= ~TileSet::Bottom; y += offset; }
+                else if( gtk_theming_engine_has_class( engine, GTK_STYLE_CLASS_BOTTOM ) ) { tiles &= ~TileSet::Top; h -= offset; }
+                else if( vertical ) { y += offset; h -= 2*offset; }
+                else { x+= offset; w -= 2*offset; }
+                #else
+                if( vertical ) { y += offset; h -= 2*offset; }
+                else { x+= offset; w -= 2*offset; }
+                #endif
 
-                } else {
-
-                    Style::instance().renderSliderGroove( context, x + offset, y, w - 2*offset, h, StyleOptions() );
-                }
+                // render
+                Style::instance().renderSliderGroove( context, x, y, w, h, vertical ? Vertical:StyleOptions(), tiles );
 
                 return;
 
@@ -862,10 +870,8 @@ namespace Oxygen
 
             }
 
-            #if GTK_CHECK_VERSION(2, 20, 0)
             // tool itemgroup buttons
             if( GTK_IS_TOOL_ITEM_GROUP( widget ) ) return;
-            #endif
 
             StyleOptions options( widget, state );
             options |= Blend;
@@ -1038,6 +1044,12 @@ namespace Oxygen
 
         } else if( gtk_widget_path_is_type( path, GTK_TYPE_MENU_ITEM ) ) {
 
+            if( GTK_IS_MENU_ITEM( widget ) )
+            {
+                GtkWidget* child( gtk_bin_get_child( GTK_BIN( widget ) ) );
+                Style::instance().animations().menuItemEngine().registerWidget( child );
+            }
+
             GtkWidget* parent( widget ? gtk_widget_get_parent( widget ):0L );
             AnimationData data;
             if( GTK_IS_MENU_BAR( parent ) )
@@ -2265,8 +2277,13 @@ namespace Oxygen
 
             } else if( GTK_IS_ENTRY( widget ) ) {
 
+                #if GTK_CHECK_VERSION( 3, 3, 0 )
+                y+=1; h-=2;
+                x+=3; w-=6;
+                #else
                 y-=1; h+=2;
                 x-=2; w+=4;
+                #endif
 
             } else if( GTK_IS_TREE_VIEW( widget ) ) {
 
@@ -2390,9 +2407,6 @@ namespace Oxygen
         Style::instance().windowManager().initializeHooks();
         Style::instance().shadowHelper().initializeHooks();
 
-        // also initialize dbus
-        Oxygen::DBus::instance().connect();
-
         // initialize argb hooks
         if( Style::instance().settings().argbEnabled() )
         { Style::instance().argbHelper().initializeHooks(); }
